require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_sqlreplication',
  dscmeta_resource_friendly_name: 'SqlReplication',
  dscmeta_resource_name: 'DSC_SqlReplication',
  dscmeta_module_name: 'SqlServerDsc',
  dscmeta_module_version: '14.0.0',
  docs: 'The DSC SqlReplication resource type.
         Automatically generated from version 14.0.0',
  features: ['simple_get_filter', 'canonicalize'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    dsc_workingdirectory: {
      type: 'String',
      desc: 'Publisher working directory',

      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_distributiondbname: {
      type: 'Optional[String]',
      desc: 'Distribution database name',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_uninstallwithforce: {
      type: 'Optional[Boolean]',
      desc: 'Force flag for uninstall procedure',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_instancename: {
      type: 'String',
      desc: 'SQL Server instance name where replication distribution will be configured',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_ensure: {
      type: "Optional[Enum['Present', 'Absent']]",
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_adminlinkcredentials: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: 'Distributor administration link password',
      behaviour: :parameter,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_remotedistributor: {
      type: 'Optional[String]',
      desc: 'Distributor server name if configuring publisher with remote distributor',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_distributormode: {
      type: "Enum['Local', 'Remote']",
      desc: ' ',

      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_usetrustedconnection: {
      type: 'Optional[Boolean]',
      desc: 'Publisher security mode',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
  },
)
