require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_sqlrs',
  dscmeta_resource_friendly_name: 'SqlRS',
  dscmeta_resource_name: 'DSC_SqlRS',
  dscmeta_module_name: 'SqlServerDsc',
  dscmeta_module_version: '14.0.0',
  docs: 'The DSC SqlRS resource type.
         Automatically generated from version 14.0.0',
  features: ['simple_get_filter', 'canonicalize'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    dsc_suppressrestart: {
      type: 'Optional[Boolean]',
      desc: 'Reporting Services need to be restarted after initialization or settings change. If this parameter is set to $true, Reporting Services will not be restarted, even after initialization.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_databaseservername: {
      type: 'String',
      desc: 'Name of the SQL Server to host the Reporting Service database.',

      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_databaseinstancename: {
      type: 'String',
      desc: 'Name of the SQL Server instance to host the Reporting Service database.',

      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_reportserverreservedurl: {
      type: 'Optional[Array[String]]',
      desc: "Report Server URL reservations. Optional. If not specified, 'http://+:80' URL reservation will be used.",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_instancename: {
      type: 'String',
      desc: 'Name of the SQL Server Reporting Services instance to be configured.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_reportsreservedurl: {
      type: 'Optional[Array[String]]',
      desc: "Report Manager/Report Web App URL reservations. Optional. If not specified, 'http://+:80' URL reservation will be used.",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_reportsvirtualdirectory: {
      type: 'Optional[String]',
      desc: 'Report Manager/Report Web App virtual directory name. Optional.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_reportservervirtualdirectory: {
      type: 'Optional[String]',
      desc: 'Report Server Web Service virtual directory. Optional.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_usessl: {
      type: 'Optional[Boolean]',
      desc: 'If connections to the Reporting Services must use SSL. If this parameter is not assigned a value, the default is that Reporting Services does not use SSL.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_isinitialized: {
      type: 'Optional[Boolean]',
      desc: 'Is the Reporting Services instance initialized.',
      behaviour: :read_only,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
  },
)
