require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_sqlwindowsfirewall',
  dscmeta_resource_friendly_name: 'SqlWindowsFirewall',
  dscmeta_resource_name: 'DSC_SqlWindowsFirewall',
  dscmeta_module_name: 'SqlServerDsc',
  dscmeta_module_version: '14.0.0',
  docs: 'The DSC SqlWindowsFirewall resource type.
         Automatically generated from version 14.0.0',
  features: ['simple_get_filter', 'canonicalize'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    dsc_sourcepath: {
      type: 'Optional[String]',
      desc: 'UNC path to the root of the source files for installation.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_browserfirewall: {
      type: 'Optional[Boolean]',
      desc: 'Is the firewall rule for the Browser enabled?',
      behaviour: :read_only,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_ensure: {
      type: "Optional[Enum['Present', 'Absent']]",
      desc: 'An enumerated value that describes if the SQL firewall rules are is expected to be enabled on the machine. Present {default}   Absent    ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_sourcecredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: "Credentials used to access the path set in the parameter 'SourcePath'.",
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_instancename: {
      type: 'String',
      desc: 'SQL instance to enable firewall rules for.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_integrationservicesfirewall: {
      type: 'Optional[Boolean]',
      desc: 'Is the firewall rule for the Integration Services enabled?',
      behaviour: :read_only,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_features: {
      type: 'String',
      desc: 'SQL features to enable firewall rules for.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_reportingservicesfirewall: {
      type: 'Optional[Boolean]',
      desc: 'Is the firewall rule for Reporting Services enabled?',
      behaviour: :read_only,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_databaseenginefirewall: {
      type: 'Optional[Boolean]',
      desc: 'Is the firewall rule for the Database Engine enabled?',
      behaviour: :read_only,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_analysisservicesfirewall: {
      type: 'Optional[Boolean]',
      desc: 'Is the firewall rule for Analysis Services enabled?',
      behaviour: :read_only,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
  },
)
